@@ -224,7 +224,7 @@ class OKULARCORE_EXPORT Generator : public QObject
         /**
          * Destroys the generator.
          */
-        virtual ~Generator();
+        ~Generator() override;
 
         /**
          * Loads the document with the given @p fileName and fills the
@@ -455,7 +455,7 @@ class OKULARCORE_EXPORT Generator : public QObject
          *
          * @since 0.19 (KDE 4.13)
          */
-        void setDPI(const QSizeF &dpi);
+        void setDPI(const QSizeF &dpi); // TODO remove the & when we do a BIC change elsewhere
 
         /**
          * Returns the 'layers model' object of the document or NULL if
@@ -524,7 +524,7 @@ class OKULARCORE_EXPORT Generator : public QObject
          * @warning this method may be executed in its own separated thread if the
          * @ref Threaded is enabled!
          */
-        virtual QImage image( PixmapRequest *page );
+        virtual QImage image( PixmapRequest *request );
 
         /**
          * Returns the text page for the given @p request.
@@ -600,12 +600,6 @@ class OKULARCORE_EXPORT Generator : public QObject
          */
         void requestFontData(const Okular::FontInfo &font, QByteArray *data);
 
-        /**
-         * Returns the last print error in case print() failed
-         * @since 0.11 (KDE 4.5)
-         */
-        Okular::Generator::PrintError printError() const;
-
         /**
          * This method can be called to trigger a partial pixmap update for the given request
          * Make sure you call it in a way it's executed in the main thread.
@@ -614,6 +608,13 @@ class OKULARCORE_EXPORT Generator : public QObject
         void signalPartialPixmapRequest( Okular::PixmapRequest *request, const QImage &image );
 
     protected:
+        /**
+         * Returns the last print error in case print() failed
+         * @since 0.11 (KDE 4.5)
+         */
+        // TODO Make print() return a PrintError instead of bool and remove this function when a BIC change happens somewhere else
+        Q_INVOKABLE Okular::Generator::PrintError printError() const;
+
         /// @cond PRIVATE
         Generator(GeneratorPrivate &dd, QObject *parent, const QVariantList &args);
         Q_DECLARE_PRIVATE( Generator )
@@ -625,9 +626,6 @@ class OKULARCORE_EXPORT Generator : public QObject
 
     private:
         Q_DISABLE_COPY( Generator )
-
-        Q_PRIVATE_SLOT( d_func(), void pixmapGenerationFinished() )
-        Q_PRIVATE_SLOT( d_func(), void textpageGenerationFinished() )
 };
 
 /**
