@@ -24,6 +24,7 @@
 #include "../form.h"
 #include "kjs_data_p.h"
 #include "kjs_field_p.h"
+#include "kjs_ocg_p.h"
 
 using namespace Okular;
 
@@ -129,6 +130,21 @@ static KJSObject docGetExternal( KJSContext *, void *object )
     return KJSBoolean( !isShell );
 }
 
+// Document.numFields
+static KJSObject docGetNumFields( KJSContext *, void *object )
+{
+    const DocumentPrivate *doc = reinterpret_cast< DocumentPrivate* >( object );
+
+    unsigned int numFields = 0;
+
+    for ( const Page * pIt : qAsConst(doc->m_pagesVector) )
+    {
+        numFields += pIt->formFields().size();
+    }
+
+    return KJSNumber( numFields );
+}
+
 
 static KJSObject docGetInfo( KJSContext *ctx, void *object )
 {
@@ -195,7 +211,7 @@ static KJSObject docGetField( KJSContext *context, void *object,
         QLinkedList< Okular::FormField * >::const_iterator ffIt = pageFields.constBegin(), ffEnd = pageFields.constEnd();
         for ( ; ffIt != ffEnd; ++ffIt )
         {
-            if ( (*ffIt)->name() == cName )
+            if ( (*ffIt)->fullyQualifiedName() == cName )
             {
                 return JSField::wrapField( context, *ffIt, *pIt );
             }
@@ -248,6 +264,55 @@ static KJSObject docSyncAnnotScan( KJSContext *, void *,
     return KJSUndefined();
 }
 
+// Document.getNthFieldName
+static KJSObject docGetNthFieldName( KJSContext *ctx, void *object,
+                                   const KJSArguments &arguments )
+{
+    const DocumentPrivate *doc = reinterpret_cast< DocumentPrivate* >( object );
+
+    int numField = arguments.at( 0 ).toInt32( ctx );
+
+    for ( const Page * pIt : qAsConst(doc->m_pagesVector) )
+    {
+        const QLinkedList< Okular::FormField * > pageFields = pIt->formFields();
+        
+        if(numField < pageFields.size())
+        {
+            const auto ffIt = pageFields.begin() + numField;
+            
+            return KJSString( (*ffIt)->fullyQualifiedName() );
+        }
+
+        numField -= pageFields.size();
+    }
+
+    return KJSUndefined();
+}
+
+static KJSObject docGetOCGs( KJSContext *ctx, void *object,
+                                   const KJSArguments & )
+{
+    const DocumentPrivate *doc = reinterpret_cast< DocumentPrivate* >( object );
+
+    QAbstractItemModel * model = doc->m_parent->layersModel();
+
+    KJSArray array( ctx, model->rowCount() );
+
+    for(int i = 0;i < model->rowCount();++i){
+        for(int j = 0;j < model->columnCount();++j){
+            const QModelIndex index = model->index( i, j );
+            
+            KJSObject item = JSOCG::wrapOCGObject( ctx, model, i, j );
+            item.setProperty( ctx, QStringLiteral("name"), model->data( index , Qt::DisplayRole ).toString() );
+            item.setProperty( ctx, QStringLiteral("initState"), model->data( index , Qt::CheckStateRole ).toBool() );
+
+            array.setProperty( ctx, QString::number( i ), item );
+        }
+    }
+
+    return array;
+}
+
 void JSDocument::initType( KJSContext *ctx )
 {
     assert( g_docProto );
@@ -266,6 +331,7 @@ void JSDocument::initType( KJSContext *ctx )
     g_docProto->defineProperty( ctx, QStringLiteral("permStatusReady"), docGetPermStatusReady );
     g_docProto->defineProperty( ctx, QStringLiteral("dataObjects"), docGetDataObjects );
     g_docProto->defineProperty( ctx, QStringLiteral("external"), docGetExternal );
+    g_docProto->defineProperty( ctx, QStringLiteral("numFields"), docGetNumFields );
 
     // info properties
     g_docProto->defineProperty( ctx, QStringLiteral("info"), docGetInfo );
@@ -281,6 +347,8 @@ void JSDocument::initType( KJSContext *ctx )
     g_docProto->defineFunction( ctx, QStringLiteral("getPageRotation"), docGetPageRotation );
     g_docProto->defineFunction( ctx, QStringLiteral("gotoNamedDest"), docGotoNamedDest );
     g_docProto->defineFunction( ctx, QStringLiteral("syncAnnotScan"), docSyncAnnotScan );
+    g_docProto->defineFunction( ctx, QStringLiteral("getNthFieldName"), docGetNthFieldName );
+    g_docProto->defineFunction( ctx, QStringLiteral("getOCGs"), docGetOCGs );
 }
 
 KJSGlobalObject JSDocument::wrapDocument( DocumentPrivate *doc )
