@@ -32,7 +32,7 @@ class Scripter
         Scripter(const Scripter &) = delete;
         Scripter &operator=(const Scripter &) = delete;
 
-        QString execute( ScriptType type, const QString &script );
+        void execute( ScriptType type, const QString &script );
 
         void setEvent( Event *event );
         Event *event() const;
