@@ -36,7 +36,7 @@ class EBook_CHM : public EBook
 {
 	public:
 		EBook_CHM();
-		~EBook_CHM();
+		~EBook_CHM() override;
 
 		/*!
 		 * \brief Attempts to load chm file.
@@ -47,20 +47,20 @@ class EBook_CHM : public EBook
 		 * if files linked to this one are present locally (like MSDN).
 		 * \ingroup init
 		 */
-		bool	load( const QString& archiveName );
+		bool	load( const QString& archiveName ) override;
 
 		/*!
 		 * \brief Closes all the files, and frees the appropriate data.
 		 * \ingroup init
 		 */
-		virtual void close();
+		void close() override;
 
 		/*!
 		 * \brief Gets the title name of the opened ebook.
 		 * \return The name of the opened document, or an empty string if no ebook has been loaded.
 		 * \ingroup information
 		 */
-		virtual QString title() const;
+		QString title() const override;
 
 		/*!
 		 * \brief Gets the default URL of the e-book which should be opened when the book it first open
@@ -69,14 +69,14 @@ class EBook_CHM : public EBook
 		 *         the root of the archive filesystem. If no book has been opened, returns "/".
 		 * \ingroup information
 		 */
-		virtual QUrl homeUrl() const;
+		QUrl homeUrl() const override;
 
 		/*!
          * \brief Checks whether the specific feature is present in this file.
          * \return true if it is available; false otherwise.
          * \ingroup information
          */
-        virtual bool  hasFeature( Feature code ) const;
+        bool  hasFeature( Feature code ) const override;
 
 		/*!
 		 * \brief Parses and fills up the Table of Contents (TOC)
@@ -87,7 +87,7 @@ class EBook_CHM : public EBook
 		 *         by really buggy files; please report a bug if the file is opened ok under Windows.
 		 * \ingroup fileparsing
 		 */
-		virtual bool getTableOfContents( QList< EBookTocEntry >& toc ) const;
+		bool getTableOfContents( QList< EBookTocEntry >& toc ) const override;
 
 		/*!
 		 * \brief Parses the index table
@@ -98,7 +98,7 @@ class EBook_CHM : public EBook
 		 *         by really buggy chm file; so far it never happened on indexes.
 		 * \ingroup fileparsing
 		 */
-		virtual bool getIndex( QList< EBookIndexEntry >& index ) const;
+		bool getIndex( QList< EBookIndexEntry >& index ) const override;
 
 		/*!
 		 * \brief Retrieves the content associated with the url from the current ebook as QString.
@@ -113,7 +113,7 @@ class EBook_CHM : public EBook
 		 * \sa setCurrentEncoding() currentEncoding() getFileContentAsBinary()
 		 * \ingroup dataretrieve
 		 */
-		virtual bool getFileContentAsString( QString& str, const QUrl& url ) const;
+		bool getFileContentAsString( QString& str, const QUrl& url ) const override;
 
 		/*!
 		 * \brief Retrieves the content from url in current chm file to QByteArray.
@@ -127,7 +127,7 @@ class EBook_CHM : public EBook
 		 * \sa getFileContentAsString()
 		 * \ingroup dataretrieve
 		 */
-		virtual bool getFileContentAsBinary( QByteArray& data, const QUrl& url ) const;
+		bool getFileContentAsBinary( QByteArray& data, const QUrl& url ) const override;
 
 		/*!
 		 * \brief Retrieves the content size.
@@ -146,7 +146,7 @@ class EBook_CHM : public EBook
 		 *
 		 * \ingroup dataretrieve
 		 */
-		virtual bool enumerateFiles( QList<QUrl>& files );
+		bool enumerateFiles( QList<QUrl>& files ) override;
 
 		/*!
 		 * \brief Gets the Title of the page referenced by url.
@@ -155,7 +155,7 @@ class EBook_CHM : public EBook
 		 *
 		 * \ingroup dataretrieve
 		 */
-		virtual QString		getTopicByUrl ( const QUrl& url );
+		QString		getTopicByUrl ( const QUrl& url ) override;
 
 		/*!
 		 * \brief Gets the current ebook encoding (set or autodetected) as qtcodec
@@ -163,7 +163,7 @@ class EBook_CHM : public EBook
 		 *
 		 * \ingroup encoding
 		 */
-		virtual QString	currentEncoding() const;
+		QString	currentEncoding() const override;
 
 		/*!
 		 * \brief Sets the ebook encoding to use for TOC and content
@@ -171,19 +171,19 @@ class EBook_CHM : public EBook
 		 *
 		 * \ingroup encoding
 		 */
-		virtual bool setCurrentEncoding ( const char * encoding );
+		bool setCurrentEncoding ( const char * encoding ) override;
 
 		/*!
 		 * \brief Checks if this kind of URL is supported by the ebook format (i.e. could be passed to ebook functions)
 		 * \param url The url to check
 		 */
-		virtual bool isSupportedUrl( const QUrl& url );
+		bool isSupportedUrl( const QUrl& url ) override;
 
 		// Converts the string to the ebook-specific URL format
-        QUrl pathToUrl( const QString & link ) const;
+        QUrl pathToUrl( const QString & link ) const override;
 
 		// Extracts the path component from the URL
-		QString urlToPath( const QUrl& link ) const;
+		QString urlToPath( const QUrl& link ) const override;
 
 	private:
 		// Used in local parser
@@ -246,7 +246,7 @@ class EBook_CHM : public EBook
 		/*!
 		 * Parse binary TOC
 		 */
-		bool parseBinaryTOC(QList<EBookTocEntry> &data ) const;
+		bool parseBinaryTOC(QList<EBookTocEntry> &toc ) const;
 
 		//! btree string parser
 		QString getBtreeString( const QByteArray& btidx, unsigned long * offset, unsigned short * spaceLeft ) const;
@@ -260,7 +260,7 @@ class EBook_CHM : public EBook
 							  const QByteArray& urlstr,
 							  const QByteArray& strings,
 							  int offset,
-							  QList<EBookTocEntry> &data,
+							  QList<EBookTocEntry> &entries,
 							  int level ) const;
 
 		/*!
