@@ -70,8 +70,12 @@ class KDjVu
             friend class KDjVu;
 
             public:
+                Link() = default;
                 virtual ~Link();
 
+                Link(const Link &) = delete;
+                Link &operator=(const Link &) = delete;
+
                 enum LinkType { PageLink, UrlLink };
                 enum LinkArea { UnknownArea, RectArea, EllipseArea, PolygonArea };
                 virtual int type() const = 0;
@@ -130,6 +134,9 @@ class KDjVu
             public:
                 virtual ~Annotation();
 
+                Annotation(const Annotation &) = delete;
+                Annotation &operator=(const Annotation &) = delete;
+
                 enum AnnotationType { TextAnnotation, LineAnnotation };
                 virtual int type() const = 0;
                 QPoint point() const;
