@@ -83,8 +83,8 @@ TeXFont_PK::TeXFont_PK(TeXFontDefinition *parent)
   qCDebug(OkularDviDebug) << "TeXFont_PK::TeXFont_PK( parent=" << parent << ")";
 #endif
 
-  for(unsigned int i=0; i<TeXFontDefinition::max_num_of_chars_in_font; i++)
-    characterBitmaps[i] = nullptr;
+  for(auto &characterBitmap : characterBitmaps)
+    characterBitmap = nullptr;
   file = fopen(QFile::encodeName(parent->filename).constData(), "r");
   if (file == nullptr)
     qCCritical(OkularDviDebug) << i18n("Cannot open font file %1.", parent->filename) << endl;
@@ -104,9 +104,8 @@ TeXFont_PK::TeXFont_PK(TeXFontDefinition *parent)
 TeXFont_PK::~TeXFont_PK()
 {
   //@@@ Release bitmaps
-  for(unsigned int i=0; i<TeXFontDefinition::max_num_of_chars_in_font; i++) {
-    delete characterBitmaps[i];
-    characterBitmaps[i] = nullptr;
+  for(bitmap *characterBitmap : characterBitmaps) {
+    delete characterBitmap;
   }
 
   if (file != nullptr) {
@@ -275,9 +274,9 @@ glyph* TeXFont_PK::getGlyph(quint16 ch, bool generateCharacterPixmap, const QCol
       // character outline only using the alpha channel. That ensures
       // good quality rendering for overlapping characters.
       im32.fill(qRgb(color.red(), color.green(), color.blue()));
-      for(quint16 y=0; y<shrunk_height; y++) {
+      for(int y=0; y<shrunk_height; y++) {
         quint8 *destScanLine = (quint8 *)im32.scanLine(y);
-        for(quint16 col=0; col<shrunk_width; col++)
+        for(int col=0; col<shrunk_width; col++)
           destScanLine[4*col+3] = xydata[shrunk_width*y + col];
       }
     } else {
@@ -295,9 +294,9 @@ glyph* TeXFont_PK::getGlyph(quint16 ch, bool generateCharacterPixmap, const QCol
       quint16 bInv = 0xFF - color.blue();
 
       quint8 *srcScanLine = xydata;
-      for(quint16 y=0; y<shrunk_height; y++) {
-        unsigned int *destScanLine = (unsigned int *)im32.scanLine(y);
-        for(quint16 col=0; col<shrunk_width; col++) {
+      for(int y=0; y<shrunk_height; y++) {
+        unsigned int *destScanLine = reinterpret_cast<unsigned int *>(im32.scanLine(y));
+        for(int col=0; col<shrunk_width; col++) {
           quint16 data =  *srcScanLine;
           // The value stored in "data" now has the following meaning:
           // data = 0 -> white; data = 0xff -> use "color"
@@ -318,8 +317,8 @@ glyph* TeXFont_PK::getGlyph(quint16 ch, bool generateCharacterPixmap, const QCol
 
 
 
-#define        ADD(a, b)        ((quint32 *) (((char *) a) + b))
-#define        SUB(a, b)        ((quint32 *) (((char *) a) - b))
+#define        ADD(a, b)        (reinterpret_cast<quint32 *>(((char *) a) + b))
+#define        SUB(a, b)        (reinterpret_cast<quint32 *>(((char *) a) - b))
 
 
 
@@ -535,7 +534,7 @@ void TeXFont_PK::read_PK_char(unsigned int ch)
     characterBitmaps[ch]->bits = new char[size != 0 ? size : 1];
   }
 
-  cp = (quint32 *) characterBitmaps[ch]->bits;
+  cp = reinterpret_cast<quint32 *>(characterBitmaps[ch]->bits);
 
   /*
    * read character data into *cp
@@ -619,7 +618,7 @@ void TeXFont_PK::read_PK_char(unsigned int ch)
         }
         paint_switch = 1 - paint_switch;
       }
-      if (cp != ((quint32 *) (characterBitmaps[ch]->bits + bytes_wide * characterBitmaps[ch]->h)))
+      if (cp != (reinterpret_cast<quint32 *> (characterBitmaps[ch]->bits + bytes_wide * characterBitmaps[ch]->h)))
         oops(i18n("Wrong number of bits stored:  char. %1, font %2", ch, parent->filename));
       if (rows_left != 0 || h_bit != characterBitmaps[ch]->w)
         oops(i18n("Bad pk file (%1), too many bits", parent->filename));
@@ -705,7 +704,7 @@ void TeXFont_PK::read_PK_char(unsigned int ch)
         }
         paint_switch = 1 - paint_switch;
       }
-      if (cp != ((quint32 *) (characterBitmaps[ch]->bits + bytes_wide * characterBitmaps[ch]->h)))
+      if (cp != (reinterpret_cast<quint32 *> (characterBitmaps[ch]->bits + bytes_wide * characterBitmaps[ch]->h)))
         oops(i18n("Wrong number of bits stored:  char. %1, font %2", ch, parent->filename));
       if (rows_left != 0 || h_bit != characterBitmaps[ch]->w)
         oops(i18n("Bad pk file (%1), too many bits", parent->filename));
