@@ -21,7 +21,7 @@ class FictionBookGenerator : public Okular::TextDocumentGenerator
         FictionBookGenerator( QObject *parent, const QVariantList &args );
 
         // [INHERITED] reparse configuration
-        void addPages( KConfigDialog* dlg ) Q_DECL_OVERRIDE;
+        void addPages( KConfigDialog* dlg ) override;
 };
 
 #endif
