@@ -58,9 +58,9 @@ public:
     QXmlAttributes attributes;
     QVariant data;
 
-    XpsRenderNode * findChild( const QString &name );
-    QVariant getRequiredChildData( const QString &name );
-    QVariant getChildData( const QString &name );
+    const XpsRenderNode * findChild( const QString &name ) const;
+    QVariant getRequiredChildData( const QString &name ) const;
+    QVariant getChildData( const QString &name ) const;
 };
 
 struct XpsGradient
@@ -114,7 +114,7 @@ class XpsHandler: public QXmlDefaultHandler
 {
 public:
     explicit XpsHandler( XpsPage *page );
-    ~XpsHandler();
+    ~XpsHandler() override;
 
     bool startElement( const QString & nameSpace,
                        const QString & localName,
@@ -284,13 +284,13 @@ public:
     */
     XpsDocument* document(int documentNum) const;
 
-    QFont getFontByName( const QString &fontName, float size );
+    QFont getFontByName( const QString &absoluteFileName, float size );
 
     KZip* xpsArchive();
 
 
 private:
-    int loadFontByName( const QString &fontName );
+    int loadFontByName( const QString &absoluteFileName );
 
     QList<XpsDocument*> m_documents;
     QList<XpsPage*> m_pages;
@@ -317,7 +317,7 @@ class XpsGenerator : public Okular::Generator
     Q_INTERFACES( Okular::Generator )
     public:
         XpsGenerator( QObject *parent, const QVariantList &args );
-        virtual ~XpsGenerator();
+        ~XpsGenerator() override;
 
         bool loadDocument( const QString & fileName, QVector<Okular::Page*> & pagesVector ) override;
 
@@ -331,7 +331,7 @@ class XpsGenerator : public Okular::Generator
 
     protected:
         bool doCloseDocument() override;
-        QImage image( Okular::PixmapRequest *page ) override;
+        QImage image( Okular::PixmapRequest *request ) override;
         Okular::TextPage* textPage( Okular::TextRequest * request ) override;
 
     private:
