@@ -17,8 +17,8 @@
 #define VIEWERINTERFACE_EXPORT OKULARCORE_EXPORT
 #endif
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
+#include <QObject>
+#include <QString>
 
 namespace Okular {
 
@@ -31,8 +31,12 @@ namespace Okular {
 class VIEWERINTERFACE_EXPORT ViewerInterface
 {
     public:
+        ViewerInterface() {}
         virtual ~ViewerInterface() {}
 
+        ViewerInterface(const ViewerInterface &) = delete;
+        ViewerInterface &operator=(const ViewerInterface &) = delete;
+
         /**
          * Show the specified source location centrally in the viewer.
          *
