@@ -54,14 +54,14 @@ inline QPen buildPen( const Okular::Annotation *ann, double width, const QColor
 }
 
 void PagePainter::paintPageOnPainter( QPainter * destPainter, const Okular::Page * page,
-    Okular::DocumentObserver *observer, int flags, int scaledWidth, int scaledHeight, const QRect &limits )
+    Okular::DocumentObserver *observer, int flags, int scaledWidth, int scaledHeight, const QRect limits )
 {
         paintCroppedPageOnPainter( destPainter, page, observer, flags, scaledWidth, scaledHeight, limits,
                                    Okular::NormalizedRect( 0, 0, 1, 1 ), nullptr );
 }
 
 void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okular::Page * page,
-    Okular::DocumentObserver *observer, int flags, int scaledWidth, int scaledHeight, const QRect &limits,
+    Okular::DocumentObserver *observer, int flags, int scaledWidth, int scaledHeight, const QRect limits,
     const Okular::NormalizedRect &crop, Okular::NormalizedPoint *viewPortPoint )
 {
     qreal dpr = destPainter->device()->devicePixelRatioF();
@@ -109,7 +109,7 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
         /** 1 - RETRIEVE THE 'PAGE+ID' PIXMAP OR A SIMILAR 'PAGE' ONE **/
         const QPixmap *p = page->_o_nearestPixmap( observer, dScaledWidth, dScaledHeight );
 
-        if (p != NULL) {
+        if (p != nullptr) {
             pixmap = *p;
             pixmap.setDevicePixelRatio( qApp->devicePixelRatio() );
         }
@@ -372,7 +372,7 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
                     break;
                 case Okular::SettingsCore::EnumRenderMode::BlackWhite:
                     // Manual Gray and Contrast
-                    unsigned int * data = (unsigned int *)backImage.bits();
+                    unsigned int * data = reinterpret_cast<unsigned int *>(backImage.bits());
                     int val, pixels = backImage.width() * backImage.height(),
                         con = Okular::Settings::bWContrast(), thr = 255 - Okular::Settings::bWThreshold();
                     for( int i = 0; i < pixels; ++i )
@@ -400,7 +400,7 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
         if ( bufferedHighlights )
         {
             // draw highlights that are inside the 'limits' paint region
-            for (const auto& highlight : *bufferedHighlights)
+            for (const auto& highlight : qAsConst(*bufferedHighlights))
             {
                 const Okular::NormalizedRect & r = highlight.second;
                 // find out the rect to highlight on pixmap
@@ -653,10 +653,6 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
                     QPixmap pixmap = GuiUtils::iconLoader()->loadIcon( text->textIcon().toLower(), KIconLoader::User, 32, KIconLoader::DefaultState, QStringList(), &path, true );
                     if ( path.isEmpty() )
                         pixmap = GuiUtils::iconLoader()->loadIcon( text->textIcon().toLower(), KIconLoader::NoGroup, 32 );
-                    QRect annotBoundary2 = QRect( annotBoundary.topLeft(), QSize( TEXTANNOTATION_ICONSIZE * dpr, TEXTANNOTATION_ICONSIZE * dpr ) );
-                    QRect annotRect2 = annotBoundary2.intersected( limits );
-                    QRect innerRect2( annotRect2.left() - annotBoundary2.left(), annotRect2.top() -
-                    annotBoundary2.top(), annotRect2.width(), annotRect2.height() );
 
                     QPixmap scaledCroppedPixmap = pixmap.scaled(TEXTANNOTATION_ICONSIZE * dpr, TEXTANNOTATION_ICONSIZE * dpr).copy(dInnerRect.toAlignedRect());
                     scaledCroppedPixmap.setDevicePixelRatio(dpr);
@@ -795,7 +791,7 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
 
 
 /** Private Helpers :: Pixmap conversion **/
-void PagePainter::cropPixmapOnImage( QImage & dest, const QPixmap * src, const QRect & r )
+void PagePainter::cropPixmapOnImage( QImage & dest, const QPixmap * src, const QRect r )
 {
     qreal dpr = src->devicePixelRatioF();
 
@@ -851,7 +847,7 @@ void PagePainter::changeImageAlpha( QImage & image, unsigned int destAlpha )
 {
     image = image.convertToFormat(QImage::Format_ARGB32);
     // iterate over all pixels changing the alpha component value
-    unsigned int * data = (unsigned int *)image.bits();
+    unsigned int * data = reinterpret_cast<unsigned int *>(image.bits());
     unsigned int pixels = image.width() * image.height();
 
     int source, sourceAlpha;
@@ -990,11 +986,12 @@ LineAnnotPainter::LineAnnotPainter( const Okular::LineAnnotation * a, QSizeF pag
 
 void LineAnnotPainter::draw( QImage &image ) const
 {
-    if ( la->transformedLinePoints().count() == 2 )
+    const QLinkedList<Okular::NormalizedPoint> transformedLinePoints = la->transformedLinePoints();
+    if ( transformedLinePoints.count() == 2 )
     {
         const Okular::NormalizedPoint delta {
-            la->transformedLinePoints().last().x - la->transformedLinePoints().first().x,
-            la->transformedLinePoints().first().y - la->transformedLinePoints().last().y
+            transformedLinePoints.last().x - transformedLinePoints.first().x,
+            transformedLinePoints.first().y - transformedLinePoints.last().y
         };
         const double angle { atan2( delta.y * aspectRatio, delta.x ) };
         const double cosA { cos( -angle ) };
@@ -1002,8 +999,8 @@ void LineAnnotPainter::draw( QImage &image ) const
         const QTransform tmpMatrix = QTransform {
             cosA, sinA / aspectRatio,
             -sinA, cosA / aspectRatio,
-            la->transformedLinePoints().first().x,
-            la->transformedLinePoints().first().y };
+            transformedLinePoints.first().x,
+            transformedLinePoints.first().y };
         const double deaspectedY { delta.y * aspectRatio };
         const double mainSegmentLength { sqrt( delta.x * delta.x + deaspectedY * deaspectedY ) };
         const double lineendSize { std::min( 6. * la->style().width() / pageSize.width(), mainSegmentLength / 2. ) };
@@ -1013,7 +1010,7 @@ void LineAnnotPainter::draw( QImage &image ) const
         drawLeaderLine( 0., image, tmpMatrix );
         drawLeaderLine( mainSegmentLength, image, tmpMatrix );
     }
-    else if ( la->transformedLinePoints().count() > 2 )
+    else if ( transformedLinePoints.count() > 2 )
     {
         drawMainLine( image );
     }
