@@ -31,14 +31,14 @@ class PropertiesDialog : public KPageDialog
 
   public:
         PropertiesDialog( QWidget *parent, Okular::Document *doc );
-        virtual ~PropertiesDialog();
+        ~PropertiesDialog() override;
 
     private Q_SLOTS:
         void pageChanged( KPageWidgetItem *, KPageWidgetItem * );
         void slotFontReadingProgress( int page );
         void slotFontReadingEnded();
         void reallyStartFontReading();
-        void showFontsMenu(const QPoint &pos);
+        void showFontsMenu(const QPoint pos);
 
     private:
         Okular::Document * m_document;
@@ -56,7 +56,7 @@ class FontsListModel
 
   public:
     explicit FontsListModel( QObject * parent = nullptr );
-    virtual ~FontsListModel();
+    ~FontsListModel() override;
 
     // reimplementations from QAbstractTableModel
     int columnCount( const QModelIndex &parent = QModelIndex() ) const override;
