@@ -50,6 +50,9 @@ class SidebarItem : public QListWidgetItem
             setToolTip( text );
         }
 
+        SidebarItem(const SidebarItem &) = delete;
+        SidebarItem &operator=(const SidebarItem &) = delete;
+
         QWidget* widget() const
         {
             return m_widget;
@@ -218,6 +221,7 @@ QSize SidebarDelegate::sizeHint( const QStyleOptionViewItem &option, const QMode
 /* A custom list widget that ignores the events for disabled items */
 class SidebarListWidget : public QListWidget
 {
+    Q_OBJECT
     public:
         SidebarListWidget( QWidget *parent = Q_NULLPTR );
         ~SidebarListWidget() override;
@@ -553,7 +557,7 @@ void Sidebar::setMainWidget( QWidget *widget )
         if ( !d->splitterSizesSet )
         {
             QList<int> splitterSizes = Okular::Settings::splitterSizes();
-            if ( !splitterSizes.count() )
+            if ( splitterSizes.isEmpty() )
             {
                 // the first time use 1/10 for the panel and 9/10 for the pageView
                 splitterSizes.push_back( 50 );
@@ -760,7 +764,7 @@ void Sidebar::saveSplitterSize() const
     Okular::Settings::self()->save();
 }
 
-void Sidebar::listContextMenu( const QPoint &pos )
+void Sidebar::listContextMenu( const QPoint pos )
 {
     QMenu menu( this );
     menu.setTitle( i18n( "Okular" ) );
