@@ -21,7 +21,7 @@ class OKULARPART_EXPORT Sidebar : public QWidget
     Q_OBJECT
     public:
         explicit Sidebar( QWidget *parent = nullptr );
-        ~Sidebar();
+        ~Sidebar() override;
 
         int addItem( QWidget *widget, const QIcon &icon, const QString &text );
 
@@ -56,7 +56,7 @@ class OKULARPART_EXPORT Sidebar : public QWidget
     private Q_SLOTS:
         void itemClicked( QListWidgetItem *item );
         void splitterMoved( int pos, int index );
-        void listContextMenu( const QPoint & );
+        void listContextMenu( const QPoint );
         void showTextToggled( bool );
         void iconSizeChanged( QAction *action );
 
