@@ -10,26 +10,32 @@
 #ifndef URL_UTILS_H
 #define URL_UTILS_H
 
-#include <QRegExp>
+#include <QRegularExpression>
 
 namespace UrlUtils
 {
     QString getUrl( QString txt )
     {
         // match the url
-        QRegExp reg( QStringLiteral( "\\b((https?|ftp)://(www\\d{0,3}[.])?[\\S]+)|((www\\d{0,3}[.])[\\S]+)" ) );
+        QRegularExpression reg( QStringLiteral( "\\b((https?|ftp)://(www\\d{0,3}[.])?[\\S]+)|((www\\d{0,3}[.])[\\S]+)" ) );
         // blocks from detecting invalid urls
-        QRegExp reg1( QStringLiteral( "[\\w'\"\\(\\)]+https?://|[\\w'\"\\(\\)]+ftp://|[\\w'\"\\(\\)]+www\\d{0,3}[.]" ) );
-        txt = txt.remove( QStringLiteral("\n") );
-        if( reg1.indexIn( txt ) < 0 && reg.indexIn( txt ) >= 0 && QUrl( reg.cap() ).isValid() )
-        {
-            QString url = reg.cap();
-            if( url.startsWith( QLatin1String("www") ) )
+        QRegularExpression reg1( QStringLiteral( "[\\w'\"\\(\\)]+https?://|[\\w'\"\\(\\)]+ftp://|[\\w'\"\\(\\)]+www\\d{0,3}[.]" ) );
+        txt = txt.remove( QLatin1Char('\n') );
+
+        if ( reg1.match( txt ).hasMatch() ) { // return early if there is a match (url is not valid)
+            return QString();
+        }
+
+        QRegularExpressionMatch match = reg.match( txt );
+        QString url = match.captured();
+        if ( match.hasMatch() && QUrl( url ).isValid() ) {
+            if( url.startsWith( QLatin1String("www") ) ) {
                 url.prepend( QLatin1String("http://") );
+            }
             return url;
         }
-        else
-            return QString();
+
+        return QString();
     }
 }
 
